@@ -73,7 +73,6 @@ var contacts = new Array();
 var ballContacts = new Array();
 var goalUnlocked;
 var lastContact;
-var ballContacts;
 var wallComponent = Qt.createComponent("qrc:/gcompris/src/activities/balancebox/Wall.qml");
 var contactComponent = Qt.createComponent("qrc:/gcompris/src/activities/balancebox/BalanceContact.qml");
 var balanceItemComponent = Qt.createComponent("qrc:/gcompris/src/activities/balancebox/BalanceItem.qml");
@@ -165,19 +164,18 @@ function sinDeg(num)
 function moveBall()
 {
     var dt = step / 1000;
-    var dvx = ((m*g*dt) * sinDeg(items.tilt.yRotation)) / m;
-    var dvy = ((m*g*dt) * sinDeg(items.tilt.xRotation)) / m;
+    var dvx = g*dt * sinDeg(items.tilt.yRotation);
+    var dvy = g*dt * sinDeg(items.tilt.xRotation);
 
 //    console.log("moving ball: dv: " + items.ball.body.linearVelocity.x
 //            + "/" + items.ball.body.linearVelocity.y
 //            +  " -> " + (items.ball.body.linearVelocity.x+dvx)
 //            + "/" + (items.ball.body.linearVelocity.y+dvy));
-    
+
     items.ball.body.linearVelocity.x += dvx * vFactor;
     items.ball.body.linearVelocity.y += dvy * vFactor;
     
     checkBallContacts();
-
 }
 
 function checkBallContacts()
@@ -234,6 +232,11 @@ function finishBall(won, x, y)
 function stop() {
     // reset everything
     tearDown();
+
+    if(goal) {
+        goal.destroy()
+        goal = null
+    }
     // unlock screen orientation
     if (GCompris.ApplicationInfo.isMobile) {
         GCompris.ApplicationInfo.setKeepScreenOn(false);
@@ -265,7 +268,7 @@ function incubateObject(targetArr, component, properties)
     }
     incubators.push(incubator);
     if (incubator.status === Qml.Component.Ready)
-        targetAttr.push(incubator.object);
+        targetArr.push(incubator.object);
     else if (incubator.status === Qml.Component.Loading) {
         pendingObjects++;
         incubator.onStatusChanged = function(status) {
@@ -290,7 +293,6 @@ function incubateObject(targetArr, component, properties)
 
 function initMap()
 {
-    var modelMap = new Array();
     incubators = new Array();
     goalUnlocked = true;
     finishRunning = false;
@@ -301,7 +303,8 @@ function initMap()
         for (var col = 0; col < map[row].length; col++) {
             var x = col * items.cellSize;
             var y = row * items.cellSize;
-            var orderNum = (map[row][col] & 0xFF00) >> 8;
+            var currentCase = map[row][col];
+            var orderNum = (currentCase & 0xFF00) >> 8;
             // debugging:
             if (debugDraw) {
                 try {
@@ -319,7 +322,7 @@ function initMap()
                     console.error("Error creating object: " + e);
                 }
             }
-            if (map[row][col] & NORTH) {
+            if (currentCase & NORTH) {
                 incubateObject(walls, wallComponent, {
                                    x: x-items.wallSize/2,
                                    y: y-items.wallSize/2,
@@ -327,7 +330,7 @@ function initMap()
                                    height: items.wallSize,
                                    shadow: false});
             }
-            if (map[row][col] & SOUTH) {
+            if (currentCase & SOUTH) {
                 incubateObject(walls, wallComponent, {
                                    x: x-items.wallSize/2,
                                    y: y+items.cellSize-items.wallSize/2,
@@ -335,7 +338,7 @@ function initMap()
                                    height: items.wallSize,
                                    shadow: false});
             }
-            if (map[row][col] & EAST) {
+            if (currentCase & EAST) {
                 incubateObject(walls, wallComponent, {
                                    x: x+items.cellSize-items.wallSize/2,
                                    y: y-items.wallSize/2,
@@ -343,7 +346,7 @@ function initMap()
                                    height: items.cellSize+items.wallSize,
                                    shadow: false});
             }
-            if (map[row][col] & WEST) {
+            if (currentCase & WEST) {
                 incubateObject(walls, wallComponent, {
                                    x: x-items.wallSize/2,
                                    y: y-items.wallSize/2,
@@ -352,16 +355,17 @@ function initMap()
                                    shadow: false});
             }
 
-            if (map[row][col] & START) {
+            if (currentCase & START) {
                 items.ball.x = col * items.cellSize + items.wallSize;
                 items.ball.y = row * items.cellSize + items.wallSize;
                 items.ball.visible = true;
             }
             
-            if (map[row][col] & GOAL) {
+            if (currentCase & GOAL) {
                 var goalX = col * items.cellSize + items.wallSize/2;
                 var goalY = row * items.cellSize + items.wallSize/2;
-                goal = createObject(goalComponent, {
+                if(goal === null) {
+                    goal = createObject(goalComponent, {
                                         x: goalX,
                                         y: goalY,
                                         width: items.cellSize - items.wallSize,
@@ -369,9 +373,17 @@ function initMap()
                                         imageSource: baseUrl + "/door_closed.svg",
                                         categories: items.goalType,
                                         sensor: true});
+                }
+                else {
+                    goal.x = goalX;
+                    goal.y = goalY;
+                    goal.width = items.cellSize - items.wallSize;
+                    goal.height = goal.width;
+                    goal.imageSource = baseUrl + "/door_closed.svg";
+                }
             }
             
-            if (map[row][col] & HOLE) {
+            if (currentCase & HOLE) {
                 var holeX = col * items.cellSize + items.wallSize;
                 var holeY = row * items.cellSize + items.wallSize;
                 incubateObject(holes, balanceItemComponent, {
@@ -454,9 +466,6 @@ function tearDown()
         contacts.length = 0;
     }
     lastContact = 0;
-    if (goal)
-        goal.destroy();
-    goal = null;
     items.tilt.xRotation = 0;
     items.tilt.yRotation = 0;
     ballContacts = new Array();
@@ -533,7 +542,7 @@ function processKeyRelease(key)
 }
 
 function nextLevel() {
-    if(numberOfLevel <= ++currentLevel ) {
+    if(numberOfLevel <= ++currentLevel) {
         currentLevel = 0
     }
     initLevel();
