@@ -19,7 +19,7 @@
  *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 #include <QtDebug>
-#include <QGuiApplication>
+#include <QApplication>
 #include <QQuickWindow>
 #include <QQmlApplicationEngine>
 #include <QStandardPaths>
@@ -108,7 +108,7 @@ int main(int argc, char *argv[])
     // Disable it because we already support HDPI display natively
     qunsetenv("QT_DEVICE_PIXEL_RATIO");
 
-    QGuiApplication app(argc, argv);
+    QApplication app(argc, argv);
     app.setOrganizationName("KDE");
     app.setApplicationName(GCOMPRIS_APPLICATION_NAME);
     app.setOrganizationDomain("kde.org");
@@ -210,12 +210,6 @@ int main(int argc, char *argv[])
     // Update execution counter
     ApplicationSettings::getInstance()->setExeCount(ApplicationSettings::getInstance()->exeCount() + 1);
 
-    // Register voices-resources for current locale, updates/downloads only if
-    // not prohibited by the settings
-    if(!DownloadManager::getInstance()->areVoicesRegistered())
-        DownloadManager::getInstance()->updateResource(DownloadManager::getInstance()
-            ->getVoicesResourceForLocale(locale));
-
     if(parser.isSet(clFullscreen)) {
         isFullscreen = true;
     }
